@@ -1,18 +1,13 @@
 import torch
 from .modules import ResnetModule
 from .Model import Model
+from .concerns import Trainable
+from ..device import get_device
 
 
-class Resnet(Model):
+class Resnet(Model, Trainable):
     def __init__(self, num_classes: int, lr: float):
         super().__init__()
-        self.network = ResnetModule(num_classes)
-        self.optimizer = torch.optim.SGD(self.network.parameters(), lr=lr, momentum=0.9)
+        self.network = ResnetModule(num_classes).to(get_device())
         self.criterion = torch.nn.CrossEntropyLoss()
-
-    def train(self, x: torch.Tensor, y: torch.Tensor):
-        self.network.train()
-        self.optimizer.zero_grad()
-        loss = self.criterion(x, y)
-        loss.backward()
-        self.optimizer.step()
+        self.optimizer = torch.optim.SGD(self.network.parameters(), lr=lr, momentum=0.9)
